@@ -42,6 +42,9 @@ from univention.config_registry import ConfigRegistry
 from univention.lib.misc import custom_groupname
 from univention.testing.udm import UCSTestUDM
 from univention.testing.utils import get_ldap_connection, wait_for_listener_replication
+from univention.udm import UDM
+from univention.udm.binary_props import Base64Bzip2BinaryProperty
+from univention.udm.modules.settings_data import SettingsDataObject
 
 
 @pytest.fixture()
@@ -70,6 +73,16 @@ def keycloak_settings() -> dict:
     return settings
 
 
+@pytest.fixture()
+def keycloak_app_version() -> str:
+    apps_cache = Apps()
+    version = [
+        app.version for app in apps_cache.get_all_locally_installed_apps()
+        if app.id == "keycloak"
+    ]
+    return version[0]
+
+
 @pytest.fixture()
 def change_app_setting():
     apps_cache = Apps()
@@ -94,6 +107,19 @@ def change_app_setting():
         configure.call(app=app, set_vars=revert_changes)
 
 
+@pytest.fixture()
+def upgrade_status_obj(ucr) -> SettingsDataObject:
+    udm = UDM.admin().version(2)
+    mod = udm.get("settings/data")
+    obj = mod.get(f"cn=keycloak,cn=data,cn=univention,{ucr.get('ldap/base')}")
+    orig_value = obj.props.data.raw
+
+    yield obj
+
+    obj.props.data = Base64Bzip2BinaryProperty("data", raw_value=orig_value)
+    obj.save()
+
+
 class UnverfiedUser(object):
 
     def __init__(self, udm: UCSTestUDM, password: str = "univention"):
@@ -154,6 +180,7 @@ def keycloak_config(ucr: ConfigRegistry) -> SimpleNamespace:
     url = f"https://ucs-sso-ng.{ucr['domainname']}"
     config = {
         "url": url,
+        "admin_url": f"{url}/admin",
         "token_url": f"{url}/realms/master/protocol/openid-connect/token",
         "users_url": f"{url}/admin/realms/ucs/users",
         "client_session_stats_url": f"{url}/admin/realms/ucs/client-session-stats",
@@ -171,20 +198,15 @@ def keycloak_config(ucr: ConfigRegistry) -> SimpleNamespace:
         "login_id": "kc-login",
         "username_id": "username",
         "password_id": "password",
-        "input_error_id": "input-error",
+        "login_error_css_selector": "span[class='pf-c-alert__title kc-feedback-text']",
+        "password_update_error_css_selector": "span[class='pf-c-alert__title kc-feedback-text']",
         "wrong_password_msg": "Invalid username or password.",
         "kc_passwd_update_form_id": "kc-passwd-update-form",
         "password_confirm_id": "password-confirm",
         "password_new_id": "password-new",
-        "password_update_feedback_class": "pf-c-alert__title kc-feedback-text",
         "password_change_button_id": "kc-form-buttons",
         "password_update_failed_msg": "Update password failed",
-        "password_already_used_msg": "Changing password failed. The password was already used.",
-        "password_too_short_msg": "Changing password failed. The password is too short.",
-        "password_confirm_error_msg": "Passwords don't match.",
-        "password_confirm_error_id": "input-error-password-confirm",
-        "password_input_error_id": "input-error-password",
-        "password_input_error_msg": "Please specify password.",
+        "kc_page_title_id": "kc-page-title",
     }
     return SimpleNamespace(**config)
 
